# -*- coding: UTF-8 -*-
__author__ = "余洋"
__doc__ = "Database"
"""
  * @File    :   Database.py
  * @Time    :   2023/11/09 15:56:06
  * @Author  :   余洋
  * @Version :   0.0.1
  * @Contact :   yuyangit.0515@qq.com
  * @License :   (C)Copyright 2019-2024, 希洋 (Ship of Ocean)
  * @Desc    :   
"""

from pathlib import Path
from xy_web_settings.Section.Section import *
from uuid import uuid4


class Database(Section):
    db_host: str | None = None

    db_port: int | None = None

    db_name: str | None = None

    db_user: str | None = None

    db_password: str | None = None

    db_path: Path | None = None

    db_file: Path | None = None

    backup_path: Path | None = None

    def _load(self):
        ########## sync_data ##########

        self.db_host = self._sync_data("db_host", "127.0.0.1")

        self.db_port = self._sync_data("db_port", 3306)

        self.db_name = self._sync_data("db_name", uuid4().hex[:10])

        self.db_user = self._sync_data("db_user", uuid4().hex[:10])

        self.db_password = self._sync_data("db_password", uuid4().hex[:10])

        ########## fetch_path ##########

        self.db_path = self._fetch_path(
            "db_path",
            Path("../workspace/database/"),
        )

        self.db_file = self._fetch_path(
            "db_file_path",
            Path("../workspace/database/xy_web.sqlite3"),
        )

        self.backup_path = self._fetch_path(
            "backup_path",
            Path("../workspace/backup/database/"),
        )

        super()._load()



# -*- coding: UTF-8 -*-
__author__ = "余洋"
__doc__ = "Nginx"
"""
  * @File    :   Nginx.py
  * @Time    :   2023/11/09 15:55:43
  * @Author  :   余洋
  * @Version :   0.0.1
  * @Contact :   yuyangit.0515@qq.com
  * @License :   (C)Copyright 2019-2024, 希洋 (Ship of Ocean)
  * @Desc    :   
"""

from pathlib import Path
from xy_web_settings.Section.Section import *


class Nginx(Section):
    path: Path | None = None

    logs_path: Path | None = None

    error_log: Path | None = None

    access_log: Path | None = None

    def _load(self):
        ########## fetch_path ##########

        self.path = self._fetch_path(
            "path",
            Path("../workspace/nginx/"),
        )

        self.logs_path = self._fetch_path(
            "logs_path",
            Path("../workspace/nginx/logs/"),
        )

        self.error_log = self._fetch_path(
            "error_log",
            Path("../workspace/nginx/logs/error.log"),
        )

        self.access_log = self._fetch_path(
            "access_log",
            Path("../workspace/nginx/logs/access.log"),
        )

        super()._load()



# -*- coding: UTF-8 -*-
__author__ = "余洋"
__doc__ = "Admin"
""" 
 * @Author: 余洋 yuyangit.0515@qq.com
 * @Date: 2024-10-21 12:20:21
 * @LastEditors: 余洋 yuyangit.0515@qq.com
 * @LastEditTime: 2024-10-21 12:32:51
 * @FilePath: /xy_web_settings/xy_web_settings/Section/Admin/Admin.py
 * @Description: 这是默认设置,请设置`customMade`, 打开koroFileHeader查看配置 进行设置: https://github.com/OBKoro1/koro1FileHeader/wiki/%E9%85%8D%E7%BD%AE
 """
"""
  * @File    :   Admin.py
  * @Time    :   2023/11/09 15:56:21
  * @Author  :   余洋
  * @Version :   0.0.1
  * @Contact :   yuyangit.0515@qq.com
  * @License :   (C)Copyright 2019-2024, 希洋 (Ship of Ocean)
  * @Desc    :   
"""

from pathlib import Path
from xy_web_settings.Section.Section import *


class Admin(Section):
    name: str | None

    host: str | None

    debug_port: int | None

    release_port: int | None

    logs_path: Path | None

    admin_log: Path | None

    backup_path: Path | None

    def _load(self):
        ########## sync_data ##########

        self.name = self._sync_data("name", "Admin")

        self.host = self._sync_data("host", "0.0.0.0")

        self.debug_port = self._sync_data("debug_port", 8403)

        self.release_port = self._sync_data("release_port", 8404)

        ########## fetch_path ##########

        self.backup_path = self._fetch_path("backup_path", Path("../workspace/logs/admin/"))  # type: ignore

        self.logs_path = self._fetch_path("logs_path", Path("../workspace/logs/admin/admin.log"))  # type: ignore

        self.admin_log = self._fetch_path("admin_log", Path("../workspace/backup/admin/"))  # type: ignore

        super()._load()



# -*- coding: UTF-8 -*-
__author__ = "余洋"
__doc__ = "Workspace"
"""
  * @File    :   Workspace.py
  * @Time    :   2024/10/28 09:32:42
  * @Author  :   余洋
  * @Version :   0.0.1
  * @Contact :   yuyangit.0515@qq.com
  * @License :   (C)Copyright 2019-2024, 希洋 (Ship of Ocean)
  * @Desc    :   
"""

from pathlib import Path
from xy_web_settings.Section.Section import *


class Workspace(Section):
    path: Path | None = None

    def _load(self):
        self.path = self._fetch_path("path", Path("../workspace/"))

        super()._load()



# -*- coding: UTF-8 -*-
__author__ = "余洋"
__doc__ = "Settings"
"""
  * @File    :   Settings.py
  * @Time    :   2023/04/25 22:37:37
  * @Author  :   余洋
  * @Version :   1.0
  * @Contact :   yuyangit.0515@qq.com
  * @License :   (C)Copyright 2019-2024, 希洋 (Ship of Ocean)
  * @Desc    :   None
"""
from pathlib import Path
from xy_work.Settings.Settings import Settings as xySettings
from .Mode import Mode


class Settings(xySettings):
    GLOBAL_CFG_SETTINGS_PATH_KEY = "__xy_web_global_cfg_path_key"
    default_cfg_relative_path: Path = Path("config/xy_web.toml")
    mode: Mode = Mode.FULL

    def load(
        self,
        settings_cfg_path: Path,
        strict: bool = True,
        auto_create_path: bool = False,
        mode: int = 0,
    ):
        self.mode = Mode(mode)
        return super().load(
            settings_cfg_path,
            strict,
            auto_create_path,
        )



# -*- coding: UTF-8 -*-
__author__ = "余洋"
__doc__ = "Mode"
"""
  * @File    :   Mode.py
  * @Time    :   2023/04/25 23:59:52
  * @Author  :   余洋
  * @Version :   1.0
  * @Contact :   yuyangit.0515@qq.com
  * @License :   (C)Copyright 2019-2024, 希洋 (Ship of Ocean)
  * @Desc    :   None
"""

from enum import IntEnum


class Mode(IntEnum):
    SIMPLE = 0
    FULL = 1



# -*- coding: UTF-8 -*-
__author__ = "余洋"
__doc__ = "Development"
"""
  * @File    :   Development.py
  * @Time    :   2023/11/09 15:55:58
  * @Author  :   余洋
  * @Version :   0.0.1
  * @Contact :   yuyangit.0515@qq.com
  * @License :   (C)Copyright 2019-2024, 希洋 (Ship of Ocean)
  * @Desc    :   
"""

from xy_web_settings.Section.Section import *


class Development(Section):
    debug: bool = True

    def _load(self):
        ########## sync_data ##########
        self.debug = self._sync_data("debug", True)
        super()._load()



# -*- coding: UTF-8 -*-
__author__ = "余洋"
__doc__ = "Resource"
"""
  * @File    :   Resource.py
  * @Time    :   2023/11/09 15:55:35
  * @Author  :   余洋
  * @Version :   0.0.1
  * @Contact :   yuyangit.0515@qq.com
  * @License :   (C)Copyright 2019-2024, 希洋 (Ship of Ocean)
  * @Desc    :   
"""

from pathlib import Path
from xy_web_settings.Section.Section import *


class Resource(Section):
    media_url: str | None = None

    media_path: Path | None = None

    static_url: str | None = None

    static_path: Path | None = None

    tmp_path: Path | None = None

    template_path: Path | None = None

    def _load(self):
        ########## sync_data ##########

        self.media_url = self._sync_data(
            "media_url",
            "/media/",
        )

        self.static_url = self._sync_data(
            "static_url",
            "/static/",
        )

        ########## fetch_path ##########

        self.media_path = self._fetch_path(
            "media_path",
            Path("../media/"),
        )

        self.static_path = self._fetch_path(
            "static_path",
            Path("../static/"),
        )

        self.tmp_path = self._fetch_path(
            "tmp_path",
            Path("../workspace/tmp/"),
        )

        self.template_path = self._fetch_path(
            "template_path",
            Path("../template/"),
        )

        super()._load()



# -*- coing: UTF-8 -*-
__author__ = "余洋"
__doc__ = "Source"
"""
  * @File    :   Source.py
  * @Time    :   2023/11/09 15:54:57
  * @Author  :   余洋
  * @Version :   0.0.1
  * @Contact :   yuyangit.0515@qq.com
  * @License :   (C)Copyright 2019-2024, 希洋 (Ship of Ocean)
  * @Desc    :   
"""

from pathlib import Path
from xy_file.Object.File import File
from xy_web_settings.Section.Section import *


class Source(Section):
    path: Path | None = None

    library_path: Path | None = None

    test_path: Path | None = None

    server_path: Path | None = None

    def _load(self):
        ########## fetch_path ##########
        self.path = self._fetch_path("path", Path("../source/"))
        self.library_path = self._fetch_path("library_path", Path("../source/Library/"))
        if self.auto_create_path and self.library_path:
            File.touch(self.library_path.joinpath("__init__.py"))
        self.test_path = self._fetch_path("test_path", Path("../workspace/test/"))
        if self.auto_create_path and self.test_path:
            File.touch(self.test_path.joinpath("__init__.py"))
        self.server_path = self._fetch_path("server_path", Path("../source/Server"))
        if self.auto_create_path and self.server_path:
            File.touch(self.server_path.joinpath("__init__.py"))
        super()._load()



# -*- coding: UTF-8 -*-
__author__ = "余洋"
__doc__ = "Template"
''' 
 * @Author: 余洋 yuyangit.0515@qq.com
 * @Date: 2024-10-21 12:20:21
 * @LastEditors: 余洋 yuyangit.0515@qq.com
 * @LastEditTime: 2024-10-21 12:21:30
 * @FilePath: /xy_web_settings/xy_web_settings/ModuleData.py
 * @Description: 这是默认设置,请设置`customMade`, 打开koroFileHeader查看配置 进行设置: https://github.com/OBKoro1/koro1FileHeader/wiki/%E9%85%8D%E7%BD%AE
 '''
"""
  * @File    :   Template.py
  * @Time    :   2023/04/24 15:51:36
  * @Author  :   余洋
  * @Version :   1.0
  * @Contact :   yuyangit.0515@qq.com
  * @License :   (C)Copyright 2019-2024, 希洋 (Ship of Ocean)
  * @Desc    :   None
"""

from pathlib import Path
from importlib_resources import files
import xy_web_settings


class ModuleData:
    def __init__(self) -> None:
        self.path: Path = files(xy_web_settings.__name__).joinpath("data")  # type: ignore
        self.template_path = self.path.joinpath("template")

        self.config_path = self.template_path.joinpath("config")

        self.config_full_path = self.config_path.joinpath("full")

        self.config_simple_path = self.config_path.joinpath("simple")

        self.simple_settings_toml_template = self.config_simple_path.joinpath(
            "settings_toml.template"
        )

        self.full_settings_toml_template = self.config_full_path.joinpath(
            "settings_toml.template"
        )



# -*- coding: UTF-8 -*-
__author__ = "余洋"
__doc__ = "Site"
"""
  * @File    :   Site.py
  * @Time    :   2023/11/09 15:55:12
  * @Author  :   余洋
  * @Version :   0.0.1
  * @Contact :   yuyangit.0515@qq.com
  * @License :   (C)Copyright 2019-2024, 希洋 (Ship of Ocean)
  * @Desc    :   
"""

from pathlib import Path
from xy_web_settings.Section.Section import *
from uuid import uuid4


class Site(Section):
    host: str | None = None

    debug_port: int | None = None

    release_ports: list | None = [
        8401,
        8402,
    ]

    cookie_secret: str | None = None

    login_url: str | None = None

    logs_path: Path | None = None

    info_log: Path | None = None

    error_log: Path | None = None

    warn_log: Path | None = None

    backup_path: Path | None = None

    def _load(self):
        ########## sync_data ##########

        self.host = self._sync_data("host", "0.0.0.0")

        self.debug_port = self._sync_data("debug_port", 8400)

        self.cookie_secret = self._sync_data("cookie_secret", uuid4().hex)

        self.login_url = self._sync_data("login_url", "/site/user/login")

        ########## fetch_path ##########

        self.backup_path = self._fetch_path(
            "backup_path",
            Path("../workspace/backup/site/"),
        )

        self.logs_path = self._fetch_path(
            "logs_path",
            Path("../workspace/logs/site/"),
        )

        self.info_log = self._fetch_path(
            "info_log",
            Path("../workspace/logs/site/info.log"),
        )

        self.error_log = self._fetch_path(
            "error_log",
            Path("../workspace/logs/site/error.log"),
        )

        self.warn_log = self._fetch_path(
            "warn_log",
            Path("../workspace/logs/site/warn.log"),
        )

        super()._load()
